==> ordering-core-0.1.10.tgz: package/lib/esm/auth.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from 'axios';
let _authData;
let tokenRetrieveTimeMs = -1;
export function authorizeWithUserPass(baseUrl, tenant, basicAuthPass, username, password) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            response = yield axios({
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `username=${username}&password=${password}&grant_type=password&scope=read`,
            });
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            return true;
        }
        catch (error) {
            //console.error('Authorization error');
            //console.error(error);
            return false;
        }
    });
}
export function authorizeWithRefreshToken(baseUrl, tenant, basicAuthPass, refreshToken) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            const req = {
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `refresh_token=${refreshToken}&grant_type=refresh_token`,
            };
            //console.log(req);
            response = yield axios(req);
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            console.log('REFRESH TOKEN AUTH RESULT ***');
            console.log(_authData);
            return true;
        }
        catch (error) {
            //console.error('Authorization error');
            //console.error(error)
            return false;
        }
    });
}
export const authDataProvider = (ctx, refreshTokenStorageHandler, forceRefresh = false) => __awaiter(void 0, void 0, void 0, function* () {
    // console.log( `authDataProvider invoked ----     currentToken=${  _authData ? _authData.access_token : '(null)'   }`, );
    if (!forceRefresh && _authData && _authData.access_token) {
        // check if we can use current token
        const secondsFromRetrievingExistingToken = new Date().getTime() - tokenRetrieveTimeMs;
        const expiryIfGreaterThan = parseInt(_authData.expires_in) * 1000 * 0.95; //miliseconds
        // console.log(
        //   `--- SHOULD USE EXISTING TOKEN (${secondsFromRetrievingExistingToken} ms from retrieving, expires if >${expiryIfGreaterThan})  - result ${
        //     secondsFromRetrievingExistingToken < expiryIfGreaterThan } `,);
        if (secondsFromRetrievingExistingToken < expiryIfGreaterThan) {
            return { token: _authData.access_token, UUID: _authData.UUID };
        }
    }
    //console.log('******** GET AUTH TOKEN (REMOTE CALL) ********');
    let loginSuccess = false;
    const refreshToken = refreshTokenStorageHandler.getRefreshToken();
    if (refreshToken) {
        //console.log('*** AUTHORIZE WITH REFRESH TOKEN ');
        loginSuccess = yield authorizeWithRefreshToken(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, refreshToken);
    }
    if (!loginSuccess && ctx.anonymousAuth) {
        //console.log('**** ANONYMOUS AUTH ****');
        loginSuccess = yield authorizeWithUserPass(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, 'anonymous', '');
    }
    if (!loginSuccess) {
        return { token: '', UUID: '' };
    }
    else {
        refreshTokenStorageHandler.setRefreshToken(_authData.refresh_token);
        return { token: _authData.access_token, UUID: _authData.UUID };
    }
});
export function createAuthDataProvider(ctx, refreshTokenProvider, forceRefresh = false) {
    return () => authDataProvider(ctx, refreshTokenProvider, forceRefresh);
}
export function setAuthData(newAuthData, newTokenRetrieveTimeMs = new Date().getTime()) {
    _authData = newAuthData;
    tokenRetrieveTimeMs = newTokenRetrieveTimeMs;
}

==> ordering-core-0.1.14.tgz: package/lib/esm/auth.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from 'axios';
import { handleAPIError } from './apiTools';
let _authData;
let tokenRetrieveTimeMs = -1;
export function authorizeWithUserPass(baseUrl, tenant, basicAuthPass, username, password) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            response = yield axios({
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `username=${username}&password=${password}&grant_type=password&scope=read`,
            });
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            return true;
        }
        catch (error) {
            //console.error('Authorization error');
            //console.error(error);
            return false;
        }
    });
}
export function authorizeWithRefreshToken(baseUrl, tenant, basicAuthPass, refreshToken) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            const req = {
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `refresh_token=${refreshToken}&grant_type=refresh_token`,
            };
            //console.log(req);
            response = yield axios(req);
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            console.log('REFRESH TOKEN AUTH RESULT ***');
            console.log(_authData);
            return true;
        }
        catch (error) {
            console.error('Authorization error');
            //console.error(error)
            return false;
        }
    });
}
export const authDataProvider = (ctx, refreshTokenStorageHandler, forceRefresh = false) => __awaiter(void 0, void 0, void 0, function* () {
    // console.log( `authDataProvider invoked ----     currentToken=${  _authData ? _authData.access_token : '(null)'   }`, );
    if (!forceRefresh && _authData && _authData.access_token) {
        // check if we can use current token
        const secondsFromRetrievingExistingToken = new Date().getTime() - tokenRetrieveTimeMs;
        const expiryIfGreaterThan = parseInt(_authData.expires_in) * 1000 * 0.95; //miliseconds
        // console.log(
        //   `--- SHOULD USE EXISTING TOKEN (${secondsFromRetrievingExistingToken} ms from retrieving, expires if >${expiryIfGreaterThan})  - result ${
        //     secondsFromRetrievingExistingToken < expiryIfGreaterThan } `,);
        if (secondsFromRetrievingExistingToken < expiryIfGreaterThan) {
            return { token: _authData.access_token, UUID: _authData.UUID };
        }
    }
    //console.log('******** GET AUTH TOKEN (REMOTE CALL) ********');
    let loginSuccess = false;
    const refreshToken = refreshTokenStorageHandler.getRefreshToken(ctx.TENANT);
    if (refreshToken) {
        //console.log('*** AUTHORIZE WITH REFRESH TOKEN ');
        loginSuccess = yield authorizeWithRefreshToken(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, refreshToken);
    }
    if (!loginSuccess && ctx.anonymousAuth) {
        //console.log('**** ANONYMOUS AUTH ****');
        loginSuccess = yield authorizeWithUserPass(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, 'anonymous', '');
    }
    if (!loginSuccess) {
        return { token: '', UUID: '' };
    }
    else {
        refreshTokenStorageHandler.setRefreshToken(ctx.TENANT, _authData.refresh_token);
        return { token: _authData.access_token, UUID: _authData.UUID };
    }
});
export function createAuthDataProvider(ctx, refreshTokenProvider, forceRefresh = false) {
    return () => authDataProvider(ctx, refreshTokenProvider, forceRefresh);
}
export function setAuthData(tenant, newAuthData, refreshTokenStorageHandler, newTokenRetrieveTimeMs = new Date().getTime()) {
    _authData = newAuthData;
    tokenRetrieveTimeMs = newTokenRetrieveTimeMs;
    //TODO: dodac klucz dla storage zawierający TENANT
    refreshTokenStorageHandler.setRefreshToken(tenant, _authData.refresh_token);
}
export function clearAuthData(tenant, refreshTokenStorageHandler) {
    refreshTokenStorageHandler.clearRefreshToken(tenant);
}
export function getLoggedUserData(baseURL, token) {
    return __awaiter(this, void 0, void 0, function* () {
        const response = yield axios({
            method: 'get',
            url: `${baseURL}/auth-api/api/me`,
            headers: {
                'Content-Type': 'application/json',
                Authorization: `Bearer ${token}`,
            },
        }).catch(handleAPIError);
        return response ? response.data : null;
    });
}
